link-section-proc-macro
A proc macro for the link-section crate.
Macros
- hash
- If the input string is longer than the max length, replace the tail end of the string with the hash of the string.
- ident_
concat - Concatenate two identifiers.