hash!() { /* proc-macro */ }Expand description
If the input string is longer than the max length, replace the tail end of the string with the hash of the string.
hash!(output input (prefix) hash_length max_length valid_section_chars)
hash!() { /* proc-macro */ }If the input string is longer than the max length, replace the tail end of the string with the hash of the string.
hash!(output input (prefix) hash_length max_length valid_section_chars)